#
# spec file for package disk-encryption-tool
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# icecream 0


Name:           disk-encryption-tool
Version:        1+git20241213.2504619
Release:        1.1
Summary:        Tool to reencrypt kiwi raw images
License:        MIT
URL:            https://github.com/openSUSE/disk-encryption-tool
Source:         disk-encryption-tool-%{version}.tar
Requires:       cryptsetup
Requires:       keyutils
ExclusiveArch:  aarch64 ppc64le riscv64 x86_64
BuildArch:      noarch

%description
Convert a plain text kiwi image into one with LUKS full disk
encryption. Supports both raw and qcow2 images. It assumes that the
third partition is the root fs using btrfs.
After encrypting the disk, the fs is mounted and a new initrd
created as well as the grub2 config adjusted.

%prep
%setup -q

%build

%install
mkdir -p %buildroot/usr/lib/dracut/modules.d/95disk-encryption-tool
for i in disk-encryption-tool{,-dracut,-dracut.service} module-setup.sh; do
  cp "$i" %buildroot/usr/lib/dracut/modules.d/95disk-encryption-tool/"$i"
done
mkdir -p %buildroot/usr/bin
ln -s ../lib/dracut/modules.d/95disk-encryption-tool/disk-encryption-tool %buildroot/usr/bin

%files
%license LICENSE
/usr/bin/disk-encryption-tool
%dir /usr/lib/dracut
%dir /usr/lib/dracut/modules.d
/usr/lib/dracut/modules.d/95disk-encryption-tool

%changelog
* Mon Mar 24 2025 aplanas@suse.com
- Update to version 1+git20241213.2504619:
  * Do not mark swap as x-initrd.attach
  * Check root_options to skip cr_root encryption
* Fri Dec  6 2024 aplanas@suse.com
- Update to version 1+git20241129.1c9848e:
  * Support swap partititons
  * Drop x-initrd.mount tag in crypttab
  * Increase the key timeout to 1h
* Tue Nov 12 2024 aplanas@suse.com
- Update to version 1+git20241112.f83dfa0:
  * Move enrollment to sdbootutil
* Thu Nov  7 2024 aplanas@suse.com
- Update to version 1+git20241107.fc90da6:
  * Clean enrollment key also in the jeos module
* Thu Nov  7 2024 aplanas@suse.com
- Update to version 1+git20241107.5a2eef7:
  * Clean the enrollment key
  * Set crypttab options
  * Use sdbootutil to enroll recovery key
  * use $tmpdir/mnt instead of /mnt as it's not there in the intird
  * Fix variable name
  * Reload disk partitions after resize
  * Make only rootfs ro
  * Remove SLE15 compatibility
  * Remove GRUB2 configuration
  * Remove image encryption support
  * Remove prime support
  * Encrypt multiple disks
  * CI: Use OVMF image with included variable store
  * Revert "CI: workaround for bug#1230912"
* Thu Oct 10 2024 aplanas@suse.com
- Update to version 1+git20241008.826cb75:
  * Revert "Add systemd-repart-dracut.service"
  * CI: workaround for bug#1230912
  * Add systemd-repart-dracut.service
* Tue Aug 27 2024 aplanas@suse.com
- Update to version 1+git20240826.c956112:
  * CI: Also provide an ignition config
* Thu Aug 22 2024 aplanas@suse.com
- Update to version 1+git20240821.f98edd6:
  * CI: Pass -cpu host to QEMU
  * Fix CI
  * Add basic automated testing
  * Remove cat of issue file
* Fri Aug 16 2024 aplanas@suse.com
- Update to version 1+git20240816.42c8565:
  * Fix extra arguments in password enrollment
* Mon Aug 12 2024 aplanas@suse.com
- Update to version 1+git20240812.fd4668d:
  * Add %%pre(un)/%%post(un) calls
* Mon Aug 12 2024 aplanas@suse.com
- Update to version 1+git20240812.9dc5b0c:
  * Create initrd if only enrolled by password
  * Add enrollment systemd service
  * Add initial component with tpm2+pin
  * Rename rd.encrypt credential
  * Add 'force' in rd.encrypt creds
  * Read the password when resizing
  * Add .dir-locals.el
  * Revert "Start the module after ignition is done"
  * Use sdbootutil enroll
  * Start the module after ignition is done
* Thu Jul  4 2024 aplanas@suse.com
- Update to version 1+git20240704.5a6539c:
  * Rename variable to SDB_ADD_INITIAL_COMPONENT
* Tue Jul  2 2024 aplanas@suse.com
- Update to version 1+git20240702.24fe41e:
  * Minor fix in spec file
  * Requires qrencode
  * Makes luks2_devices global
  * Add PCR 8 if GRUB2 is detected
  * If keyctl id fails, exit early
  * Exit early if no luks2 devices present
* Thu Mar 28 2024 lnussel@suse.com
- Update to version 1+git20240328.c4935cc:
  * Check rd.encrypt systemd credential
  * Add support for TPM PIN
  * Add support for jeos-config
  * Merge jeos module diskencrypt into enroll
  * Add editorconfig
  * Fix indent
* Tue Feb 13 2024 lnussel@suse.com
- Update to version 1+git20240213.68c965a:
  * Fix pcr-oracle detection logic
  * Do not call dracut after encryption
  * Use systemd-pcrlock
  * Rename generate_key function
  * Allow to turn off disk encryption via rd.enrypt
  * Turn on messages again
* Thu Dec 21 2023 lnussel@suse.com
- Update to version 1+git20231221.d2e7fe6:
  * Fix setting separate crypt password
* Wed Dec 20 2023 lnussel@suse.com
- Update to version 1+git20231220.6a5fb7f:
  * refactor luks detection
  * Tweak combustion deps
  * Fix combustion support (boo#1218131)
* Thu Dec 14 2023 lnussel@suse.com
- Update to version 1+git20231214.1708e01:
  * Add ExclusiveArch for 64-bit EFI architectures
  * Don't set rw systems ro
* Wed Dec 13 2023 lnussel@suse.com
- Update to version 1+git20231213.cfe4cb3:
  * Drop the second wipe
  * Comment where to find the PCRs later
  * Drop pcr-oracle RSA PEM parameter
  * Include PCR#9 in the predictions
  * Drop TPM2 from cryptab
* Mon Dec 11 2023 lnussel@suse.com
- Update to version 1+git20231130.dac7e54:
  * Silence shellcheck
  * Drop TPM2 from crypttab
* Wed Nov 29 2023 lnussel@suse.com
- Update to version 1+git20231129.5fb1e1a:
  * Require tpm2.0-tools
  * FIDO2 and TPM2 dialog improvements
  * Fix yesno dialog call o_O
  * Fix partition resizing on first boot
  * Add jeos-firstboot-enroll
  * Requires pcr-enroll
  * Store generated key as 'cryptenroll' keyring
  * Update README
  * Require keyutils
  * Rename to disk-encryption-tool
* Tue Nov 14 2023 Ludwig Nussel <lnussel@suse.com>
- initial package
